@@ -11,10 +11,9 @@ our @ISA = qw(
 );
 
 our @EXPORT = qw(
-  get_info
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use Data::Dumper;
@@ -61,7 +60,7 @@ WWW::YouTube::Info - gain info on YouTube video by VIDEO_ID
 
 I guess its pretty much self-explanatory ..
 
-=head1 FUNCTIONS
+=head1 METHODS
 
 =cut
 
@@ -105,11 +104,6 @@ sub get_info {
 
 __END__
 
-=head1 EXPORT
-
-Exported by default:
-get_info
-
 =head1 HINTS
 
 Searching the internet regarding 'fmt_url_map' and/or 'get_video_info' might gain hints/information to improve L<WWW::YouTube::Info>.
